@@ -1,5 +1,5 @@
 /* OGMDvd - A wrapper library around libdvdread
- * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2012 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -134,7 +134,7 @@ dvd_open_reader (const gchar *device, GError **error)
   return reader;
 }
 
-static G_CONST_RETURN gchar *
+static const gchar *
 dvd_reader_get_id (dvd_reader_t *reader)
 {
   static gchar str[33];
@@ -788,7 +788,7 @@ ogmdvd_disc_unref (OGMDvdDisc *disc)
  *
  * Returns: The label of the DVD, or NULL
  */
-G_CONST_RETURN gchar *
+const gchar *
 ogmdvd_disc_get_label (OGMDvdDisc *disc)
 {
   g_return_val_if_fail (disc != NULL, NULL);
@@ -804,7 +804,7 @@ ogmdvd_disc_get_label (OGMDvdDisc *disc)
  *
  * Returns: The identifier, or NULL
  */
-G_CONST_RETURN gchar *
+const gchar *
 ogmdvd_disc_get_id (OGMDvdDisc *disc)
 {
   g_return_val_if_fail (disc != NULL, NULL);
@@ -820,7 +820,7 @@ ogmdvd_disc_get_id (OGMDvdDisc *disc)
  *
  * Returns: The device of the DVD.
  */
-G_CONST_RETURN gchar *
+const gchar *
 ogmdvd_disc_get_device (OGMDvdDisc *disc)
 {
   g_return_val_if_fail (disc != NULL, NULL);
@@ -860,12 +860,6 @@ ogmdvd_disc_get_n_titles (OGMDvdDisc *disc)
   return disc->ntitles;
 }
 
-static gint
-ogmdvd_title_find_by_nr (OGMDvdTitle *title, guint nr)
-{
-  return title->nr - nr;
-}
-
 /**
  * ogmdvd_disc_get_nth_title:
  * @disc: An #OGMDvdDisc
@@ -878,20 +872,23 @@ ogmdvd_title_find_by_nr (OGMDvdTitle *title, guint nr)
 OGMDvdTitle *
 ogmdvd_disc_get_nth_title (OGMDvdDisc *disc, guint nr)
 {
-  OGMDvdTitle *title = NULL;
   GSList *link;
 
   g_return_val_if_fail (disc != NULL, NULL);
   g_return_val_if_fail (nr >= 0 && nr < disc->ntitles, NULL);
 
-  link = g_slist_find_custom (disc->titles, GUINT_TO_POINTER (nr), (GCompareFunc) ogmdvd_title_find_by_nr);
-  if (link)
+  for (link = disc->titles; link; link = link->next)
   {
-    title = link->data;
-    ogmdvd_title_ref (title);
+    OGMDvdTitle *title = link->data;
+
+    if (title->nr == nr)
+    {
+      ogmdvd_title_ref (title);
+      return title;
+    }
   }
 
-  return title;
+  return NULL;
 }
 
 /**
