@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2012 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -294,7 +294,7 @@ ogmrip_codec_set_output (OGMRipCodec *codec, const gchar *output)
  *
  * Returns: the filename, or NULL
  */
-G_CONST_RETURN gchar *
+const gchar *
 ogmrip_codec_get_output (OGMRipCodec *codec)
 {
   g_return_val_if_fail (OGMRIP_IS_CODEC (codec), NULL);
