@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2012 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -325,7 +325,7 @@ ogmrip_container_set_options (OGMRipContainer *container, const gchar *section)
  *
  * Returns: The filename, or NULL
  */
-G_CONST_RETURN gchar *
+const gchar *
 ogmrip_container_get_output (OGMRipContainer *container)
 {
   g_return_val_if_fail (OGMRIP_IS_CONTAINER (container), NULL);
@@ -358,7 +358,7 @@ ogmrip_container_set_output (OGMRipContainer *container, const gchar *output)
  *
  * Returns: The label, or NULL
  */
-G_CONST_RETURN gchar *
+const gchar *
 ogmrip_container_get_label (OGMRipContainer *container)
 {
   g_return_val_if_fail (OGMRIP_IS_CONTAINER (container), NULL);
@@ -390,7 +390,7 @@ ogmrip_container_set_label (OGMRipContainer *container, const gchar *label)
  *
  * Returns: The FourCC, or NULL
  */
-G_CONST_RETURN gchar *
+const gchar *
 ogmrip_container_get_fourcc (OGMRipContainer *container)
 {
   g_return_val_if_fail (OGMRIP_IS_CONTAINER (container), NULL);
