@@ -1,5 +1,5 @@
 /* OGMRip - A DVD Encoder for GNOME
- * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2012 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -223,12 +223,24 @@ ogmrip_crop_dialog_scale_value_changed (OGMRipCropDialog *dialog, GtkWidget *sca
   gulong frame;
   gchar *text;
 
-  frame = (guint) gtk_range_get_value (GTK_RANGE (scale));
+  frame = (gulong) gtk_range_get_value (GTK_RANGE (scale));
   text = g_strdup_printf (_("Frame %lu of %lu"), frame, dialog->priv->length);
   gtk_label_set_text (GTK_LABEL (dialog->priv->label), text);
   g_free (text);
+}
 
-  ogmrip_crop_dialog_grab_frame (dialog, frame);
+static gboolean
+ogmrip_crop_dialog_scale_button_released (OGMRipCropDialog *dialog, GdkEventButton *event, GtkWidget *scale)
+{
+  if (!event || event->button == 1)
+  {
+    gulong frame;
+
+    frame = (gulong) gtk_range_get_value (GTK_RANGE (scale));
+    ogmrip_crop_dialog_grab_frame (dialog, frame);
+  }
+
+  return FALSE;
 }
 
 G_DEFINE_TYPE (OGMRipCropDialog, ogmrip_crop_dialog, GTK_TYPE_DIALOG)
@@ -291,9 +303,10 @@ ogmrip_crop_dialog_init (OGMRipCropDialog *dialog)
   dialog->priv->label = glade_xml_get_widget (xml, "frame-label");
 
   dialog->priv->scale = glade_xml_get_widget (xml, "frame-scale");
-  gtk_range_set_update_policy (GTK_RANGE (dialog->priv->scale), GTK_UPDATE_DELAYED);
   g_signal_connect_swapped (dialog->priv->scale, "value-changed",
       G_CALLBACK (ogmrip_crop_dialog_scale_value_changed), dialog);
+  g_signal_connect_swapped (dialog->priv->scale, "button-release-event",
+      G_CALLBACK (ogmrip_crop_dialog_scale_button_released), dialog);
 
   g_object_unref (xml);
 }
@@ -352,6 +365,8 @@ ogmrip_crop_dialog_new (OGMDvdTitle *title, guint left, guint top, guint right,
   frame = g_random_int_range (1, dialog->priv->length);
   gtk_range_set_value (GTK_RANGE (dialog->priv->scale), frame);
 
+  ogmrip_crop_dialog_scale_button_released (dialog, NULL, dialog->priv->scale);
+
   return GTK_WIDGET (dialog);
 }
 
