@@ -1,5 +1,5 @@
 /* OGMRip - A DVD Encoder for GNOME
- * Copyright (C) 2004-2010 Olivier Rolland <billl@users.sourceforge.net>
+ * Copyright (C) 2004-2012 Olivier Rolland <billl@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -211,7 +211,9 @@ ogmrip_pref_dialog_init (OGMRipPrefDialog *dialog)
   gtk_dialog_add_buttons (GTK_DIALOG (dialog),
       GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
       NULL);
+#if !GTK_CHECK_VERSION(2,22,0)
   gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
+#endif
   gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CLOSE);
   gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
@@ -275,6 +277,10 @@ ogmrip_pref_dialog_init (OGMRipPrefDialog *dialog)
   ogmrip_settings_bind (settings,
       OGMRIP_GCONF_ADVANCED, OGMRIP_GCONF_AFTER_ENC, G_OBJECT (widget), "active");
 
+  widget = glade_xml_get_widget (xml, "threads-spin");
+  ogmrip_settings_bind (settings,
+      OGMRIP_GCONF_ADVANCED, OGMRIP_GCONF_THREADS, G_OBJECT (widget), "value");
+
   widget = glade_xml_get_widget (xml, "keep-tmp-check");
   ogmrip_settings_bind (settings,
       OGMRIP_GCONF_ADVANCED, OGMRIP_GCONF_KEEP_TMP, G_OBJECT (widget), "active");
@@ -298,17 +304,6 @@ ogmrip_pref_dialog_init (OGMRipPrefDialog *dialog)
   gtk_file_chooser_set_action (GTK_FILE_CHOOSER (widget), 
       GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
 
-#ifndef HAVE_SYSCONF_NPROC
-  widget = glade_xml_get_widget (xml, "threads-label");
-  gtk_widget_show (widget);
-
-  widget = glade_xml_get_widget (xml, "threads-spin");
-  gtk_widget_show (widget);
-
-  ogmrip_settings_bind (settings, OGMRIP_GCONF_ADVANCED,
-      OGMRIP_GCONF_THREADS, G_OBJECT (widget), "value");
-#endif
-
   g_object_unref (xml);
 }
 
